---
title: NHN KCP 허브형 간편결제 신청방법
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
seo:
  title: KCP 허브형 간편결제 신청방법
  description: >-
    KCP는 다양한 간편결제사가 제휴되어 있어 KCP를 통해 간편결제 서비스 이용이 가능합니다. 간편결제사별로 심사 절차가 필요하므로 아래
    경로로 신청주시면 KCP 담당 부서 확인 후 심사 및 설정이 가능합니다.
  keywords:
    - KCP
    - 간편결제
tags:
  - NHN KCP
  - 간편결제
pgCompanies:
  - NHN KCP
searchTags:
  - kcp간편결제신청
  - kcp 추가신청
  - kcp 간편결제
  - kcp허브형
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="NHN KCP에서는 다양한 간편결제사가 제휴되어 있어 NHN KCP를 통해 간편결제서비스 이용이 가능합니다." />

### **NHN KCP 허브형 간편결제**

NHN KCP의 경우 이용하시는 간편결제마다 상점아이디(사이트코드)가 추가됩니다. 추가하는 간편결제사별로 심사가 필요하므로 아래 신청절차 경로를 통해 신청해주시기 바랍니다.  NHN KCP 담당 부서에서 확인 후 심사 및 설정 안내가 발송됩니다.

<Callout icon="" content=" " title="NHN KCP 지원 허브형 간편결제 보러가기 ↗" />

### **NHN KCP 간편결제 추가 절차**

1. 현재 고객사에서 사용 중인 [NHN KCP 상점관리자 페이지↗](https://partner.kcp.co.kr/auth/login)로 접속
2. 고객센터 > 질문하기 > 기타 문의 > 기타 각종문의 '포트원용 간편결제 사이트 코드 추가 요청' 기재
3. NHN KCP에서는 발급되는 사이트 코드별로 쇼핑몰의 한도 부여가 되기 때문에 사이트 코드 신청 시 한도 요청도 함께 주셔야 합니다. (기존 사이트코드에 부여된 한도 참고하여 요청)

<Indent level="1">

**문의 작성 예시**

- 포트원 솔루션 신청
- 사이트 URL(또는 APP다운로드 경로,명칭) 기재  \
  ex. 포트원용 카카오페이/네이버페이 간편결제 사이트코드 추가 신청합니다.
- 결제수단 : 신용카드 월 한도 500만원요청 포트원 제휴 수수료율(카드 3.2%)적용 요청

</Indent>

